==> trilinos_12.10.1.orig.tar.bz2: trilinos-12.10.1-Source/packages/stk/stk_mesh/stk_mesh/base/HashEntityAndEntityKey.hpp <==
// Copyright (c) 2013, Sandia Corporation.
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
// 
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
// 
//     * Neither the name of Sandia Corporation nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#ifndef STK_MESH_HASH_ENTIY_AND_ENTITY_KEY_HPP
#define STK_MESH_HASH_ENTIY_AND_ENTITY_KEY_HPP

#include <stk_mesh/base/Entity.hpp>
#include <stk_mesh/base/EntityKey.hpp>

#include <functional>

namespace std {

template<>
struct hash<stk::mesh::Entity>
{
    const size_t operator()(const stk::mesh::Entity& entity) const
    {
        return hash<uint64_t>()(entity.m_value);
    }

    const size_t operator()(const stk::mesh::Entity& entity1, const stk::mesh::Entity& entity2) const
    {
        return hash<uint64_t>()(entity1.m_value)^hash<uint64_t>()(entity2.m_value);
    }
};

template<>
struct hash<stk::mesh::EntityKey>
{
    const size_t operator()(const stk::mesh::EntityKey& entityKey) const
    {
        return hash<unsigned long long>()(entityKey.m_value);
    }

    const size_t operator()(const stk::mesh::EntityKey& entityKey1, const stk::mesh::EntityKey& entityKey2)     const
    {
        return hash<unsigned long long>()(entityKey1.m_value)^hash<unsigned long long>()(entityKey2.m_value    );
    }
};

}

#endif

==> trilinos_12.12.1.orig.tar.bz2: trilinos-12.12.1-Source/packages/stk/stk_mesh/stk_mesh/base/HashEntityAndEntityKey.hpp <==
// Copyright (c) 2013, Sandia Corporation.
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
// 
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
// 
//     * Neither the name of Sandia Corporation nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#ifndef STK_MESH_HASH_ENTIY_AND_ENTITY_KEY_HPP
#define STK_MESH_HASH_ENTIY_AND_ENTITY_KEY_HPP

#include <stk_mesh/base/Entity.hpp>
#include <stk_mesh/base/EntityKey.hpp>

#include <functional>

namespace std {

template<>
struct hash<stk::mesh::Entity>
{
    size_t operator()(const stk::mesh::Entity& entity) const
    {
        return hash<uint64_t>()(entity.m_value);
    }

    size_t operator()(const stk::mesh::Entity& entity1, const stk::mesh::Entity& entity2) const
    {
        return hash<uint64_t>()(entity1.m_value)^hash<uint64_t>()(entity2.m_value);
    }
};

template<>
struct hash<stk::mesh::EntityKey>
{
    size_t operator()(const stk::mesh::EntityKey& entityKey) const
    {
        return hash<unsigned long long>()(entityKey.m_value);
    }

    size_t operator()(const stk::mesh::EntityKey& entityKey1, const stk::mesh::EntityKey& entityKey2) const
    {
        return hash<unsigned long long>()(entityKey1.m_value)^hash<unsigned long long>()(entityKey2.m_value    );
    }
};

}

#endif
